searchData={"items":[{"type":"module","title":"SwaySock","doc":"SwaySock is a library for controlling the running [Sway](https://swaywm.org/) process through its IPC interface.\n\nYou can query the state of the window manager, listen to events, and execute sway commands. \nThis module provides the main API to interfacing with Sway via IPC","ref":"SwaySock.html"},{"type":"module","title":"Overview - SwaySock","doc":"`start_link/1` starts a Supervisor that connects to Sway's Unix Domain Socket. This implies the library is useless without a currently running sway instace.\n\nThe architecture is simple. All commands apart from `subscribe/3` are translated to IPC messages and sent to the sway socket.\nThe response is immediately read from the socket and returned as-is.\n\n`subscribe/3` is a special case. The [`i3` docs](https://i3wm.org/docs/ipc.html#_events) explain it clearly:\n\n> Caveat: As soon as you subscribe to an event, it is not guaranteed any longer that the requests to i3 are processed in order.\n> This means, the following situation can happen: You send a GET_WORKSPACES request but you receive a \"workspace\" event before receiving the reply to GET_WORKSPACES.\n> If your program does not want to cope which such kinds of race conditions (an event based library may not have a problem here), I suggest you create a separate connection to receive events.\n\nThe same applies to Sway. This library opts to open a new connection to the sway socket for each event subscription. This is always done in supervised Task.","ref":"SwaySock.html#module-overview"},{"type":"module","title":"Reply structure - SwaySock","doc":"The sway developers may change the format of replies across releases.\nUsers of this library are encouraged to refer to the sway-ipc manual (`man sway-ipc`) for the schemas of the JSON sway sends back.","ref":"SwaySock.html#module-reply-structure"},{"type":"module","title":"Examples - SwaySock","doc":"Check out the `examples/` directory.","ref":"SwaySock.html#module-examples"},{"type":"function","title":"SwaySock.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SwaySock.html#child_spec/1"},{"type":"function","title":"SwaySock.get_bar_config/2","doc":"Returns the list of configured bar IDs.\n\nWhen `bar_id` is non-empty, this function returns the configuration of the given bar instead.","ref":"SwaySock.html#get_bar_config/2"},{"type":"function","title":"SwaySock.get_binding_modes/1","doc":"Returns a list of configured binding modes","ref":"SwaySock.html#get_binding_modes/1"},{"type":"function","title":"SwaySock.get_binding_state/1","doc":"Returns the currently active binding mode.","ref":"SwaySock.html#get_binding_state/1"},{"type":"function","title":"SwaySock.get_config/1","doc":"Returns the contents of the last-loaded sway configuration","ref":"SwaySock.html#get_config/1"},{"type":"function","title":"SwaySock.get_inputs/1","doc":"Returns a list of the input devices currently available","ref":"SwaySock.html#get_inputs/1"},{"type":"function","title":"SwaySock.get_marks/1","doc":"Returns the currently set marks","ref":"SwaySock.html#get_marks/1"},{"type":"function","title":"SwaySock.get_outputs/1","doc":"Returns the list of outputs","ref":"SwaySock.html#get_outputs/1"},{"type":"function","title":"SwaySock.get_tree/1","doc":"Returns the JSON representation of sway's node tree","ref":"SwaySock.html#get_tree/1"},{"type":"function","title":"SwaySock.get_version/1","doc":"Returns version information about the current sway process","ref":"SwaySock.html#get_version/1"},{"type":"function","title":"SwaySock.get_workspaces/1","doc":"Retrieves the list of active workspaces","ref":"SwaySock.html#get_workspaces/1"},{"type":"function","title":"SwaySock.run_command/2","doc":"Runs the sway commands in `script` \n\nReturns `{:error,  }` if any of the commands in `script` fail. The second element of the tuple will be the list of errors reported by sway.\nReturns `:ok` otherwise.","ref":"SwaySock.html#run_command/2"},{"type":"function","title":"SwaySock.send_tick/2","doc":"Sends a TICK event to all clients subscribing to the event to ensure that all events prior to the tick were received.\n\nIf a payload is given, it will be included in the TICK event.\nReturns `:ok` if the message was successfully sent. Returns `:error` otherwise","ref":"SwaySock.html#send_tick/2"},{"type":"function","title":"SwaySock.start_link/1","doc":"Connects to the Sway socket. `name` identifies the connection\n\nMultiple instances of this library may be used as long as they have different `name`s.","ref":"SwaySock.html#start_link/1"},{"type":"function","title":"How to supervise - SwaySock.start_link/1","doc":"iex> children = [ {SwaySock, :my_socket} ]\n    ...> Supervisor.start_link(children, strategy: :one_for_one)","ref":"SwaySock.html#start_link/1-how-to-supervise"},{"type":"function","title":"SwaySock.subscribe/4","doc":"Creates a new linked process that invokes `callback` when any of the listed `event_types` occurs.","ref":"SwaySock.html#subscribe/4"},{"type":"function","title":"Events - SwaySock.subscribe/4","doc":"You may subscribe to any of the following events\n\n`:workspace, :output, :mode, :window, :barconfig_update, :binding, :shutdown, :tick, :bar_state_update, :input`\n\nEvents are described in the sway-ipc manual under the \"EVENTS\" section.","ref":"SwaySock.html#subscribe/4-events"},{"type":"function","title":"Callback - SwaySock.subscribe/4","doc":"The callback must accept two arguments:\n\n- The first is the the event details, and has this structure:  `{:event_name, payload}`\n  It is a two-element tuple where the first element is an atom representing the event, and the second is its payload. \n\n- The second argument is state for the callback. The return value of one invocation of the callback is used as the state for the next.\n  The state is initialized to `callback_start_state`.","ref":"SwaySock.html#subscribe/4-callback"},{"type":"type","title":"SwaySock.json/0","doc":"","ref":"SwaySock.html#t:json/0"},{"type":"exception","title":"SwaySock.NotFound","doc":"An exception raised when Sway's IPC socket cannot be found","ref":"SwaySock.NotFound.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}